@@ -6,6 +6,14 @@ YOUTUBE = oembed.OEmbedEndpoint('http://www.youtube.com/oembed', [
     'https?://youtu.be/*',
 ])
 
+SLIDESHARE = oembed.OEmbedEndpoint('http://www.slideshare.net/api/oembed/2', [
+    'http://www.slideshare.net/*/*',
+    'http://fr.slideshare.net/*/*',
+    'http://de.slideshare.net/*/*',
+    'http://es.slideshare.net/*/*',
+    'http://pt.slideshare.net/*/*',
+])
+
 FLICKR = oembed.OEmbedEndpoint('http://www.flickr.com/services/oembed/', [
     'https?://*.flickr.com/*',
 ])
@@ -17,5 +25,6 @@ VIMEO = oembed.OEmbedEndpoint('http://vimeo.com/api/oembed.json', [
 DEFAULT_ENDPOINTS = [
     YOUTUBE,
     FLICKR,
-    VIMEO
+    VIMEO,
+    SLIDESHARE
 ]
